C	TITLE: ALLMAG
C	PURPOSE: CALCULATE EARTH'S MAGNETIC FIELD
C	AUTHOR: GSFC
C	MODIFIED 11/3/75 BY JR FOR USE ON NOVA

      SUBROUTINE ALLMAG(MODEL,TM,RKM,ST,CT,SPH,CPH,BR,BT,BP,B)

C ****  SINGLE PRECISION DECK FOR OCTAL MACHINES (BCD, 026 PUNCH)
C ****  GEOCENTRIC VERSION OF GEOMAGNETIC FIELD ROUTINE
C ****  LONG DECK, THROUGH NMAX=13, FIXED INDICES WITHOUT DO LOOPS
C ****  EXECUTION TIME PER CALL FACTOR OF THREE LESS THAN SHORT DECK
C ****  PROGRAM DESIGNED AND TESTED BY E G STASSINOPOULOS AND G D MEAD,
C ****  CODE 641, NASA GODDARD SPACE FLT CTR, GREENBELT, MD 20771

C ****  INPUT: MODEL    CHOICE OF 7 MODELS - SEE BELOW
C ****         RKM      GEOCENTRIC DISTANCE IN KILOMETERS
C ****         TM       TIME IN YEARS FOR DESIRED FIELD
C ****         ST,CT    SIN + COS OF GEOCENTRIC COLATITUDE
C ****         SPH,CPH  SIN + COS OF EAST LONGITUDE
C **** OUTPUT: BR,BT,BP GEOCENTRIC FIELD COMPONENTS IN GAUSS
C ****         B        FIELD MAGNITUDE IN GAUSS
C ****  NOTE: FOR GREATEST EFFICIENCY, COMPLETE ALL CALCULATIONS WITH
C ****          ONE MODEL AND ONE TIME BEFORE CHANGING MODELS OR TIME.

      REAL   G1(13,13),GT1(13,13),GTT1(13,13),G2(13,13),GT2(13,13),
     1 GTT2(13,13),G3(13,13),GT3(13,13),GTT3(13,13),G4(13,13),
     2 GT4(13,13),GTT4(13,13),G5(13,13),GT5(13,13),GTT5(13,13),
     3 G6(13,13),GT6(13,13),GTT6(13,13),G7(13,13),GT7(13,13),GTT7(13,13)
     4 ,RLG(13,13,7),RLGT(13,13,7),RLGTT(13,13,7)
      COMMON /GGS/   GG(13,13,7),GGT(13,13,7),GGTT(13,13,7),SHMIT(13,13)
      COMMON /DIPOLE/WLONG,COLAT
      COMMON /FACTS/ T0(7),NMX(7),RISUM(7,3),G(13,13),RLSUM(7,3),TMOLD,
     A MODOLD,RAD
      EQUIVALENCE (G1(1,1),GG(1,1,1),RLG(1,1,1)), (GT1(1,1),GGT(1,1,1),RLGT(1,1,1)),
     A     (GTT1(1,1),GGTT(1,1,1),RLGTT(1,1,1)),
     B (G2(1,1),RLG(1,1,2)), (GT2(1,1),RLGT(1,1,2)), (GTT2(1,1),RLGTT(1,1,2)),
     C (G3(1,1),RLG(1,1,3)), (GT3(1,1),RLGT(1,1,3)), (GTT3(1,1),RLGTT(1,1,3)),
     D (G4(1,1),RLG(1,1,4)), (GT4(1,1),RLGT(1,1,4)), (GTT4(1,1),RLGTT(1,1,4)),
     E (G5(1,1),RLG(1,1,5)), (GT5(1,1),RLGT(1,1,5)), (GTT5(1,1),RLGTT(1,1,5)),
     F (G6(1,1),RLG(1,1,6)), (GT6(1,1),RLGT(1,1,6)), (GTT6(1,1),RLGTT(1,1,6)),
     G (G7(1,1),RLG(1,1,7)), (GT7(1,1),RLGT(1,1,7)), (GTT7(1,1),RLGTT(1,1,7))

      DATA T0/4*1960.,2*1965.,1970./,NMX/10,11,12,11,9,9,13/
      DATA    RLSUM     /-1646106.,-1795169.,-1865298.,-1777057.,-158472.,
     A-156856.,-2191704.,-62661.,-96778.,-181519.,-83555.,-9569.,-9599.,
     B-8593.,1.,-10618.,5*1./
      DATA SHMIT(1,1)/0.0/,TMOLD/0.0/,MODOLD/0/,RAD/57.29578/

C  ***** THE FOLLOWING DATA CARDS CONTAIN THE FIELD COEFFICIENTS
C  ***** FOR THE FOLLOWING SEVEN MODELS:
C  *****  G1,GT1: HENDRICKS + CAIN      99-TERM  GSFC  9/65  EPOCH 1960.
C  *****  G2,GT2,GTT2: CAIN ET. AL.    120-TERM  GSFC 12/66  EPOCH 1960.
C  *****  G3,GT3: CAIN + LANGEL        143-TERM  POGO 10/68  EPOCH 1960.
C  *****  G4,GT4: CAIN + SWEENEY       120-TERM  POGO  8/69  EPOCH 1960.
C  *****  G5,GT5: IGRF 1965.0           80-TERM       10/68  EPOCH 1965.
C  *****  G6,GT6: LEATON MALIN + EVANS 1965        80-TERM   EPOCH 1965.
C  *****          FOR MODEL 6 (LME 1965) SET RKM = 6371.2 + ALTITUDE
C  *****  G7,GT7: HURWITZ US COAST + GEODETIC S.  168-TERM   EPOCH 1970.

      DATA G1 / 10., -304249.,-15361.,13009.,9576.,-2277.,498.,709.,48.,99.,3*0.,
     A 57748.,-21616.,30002.,-19870.,8028.,3595.,607.,-572.,67.,29.,3*0.,-19498.,
     B 2043.,15853.,12904.,5026.,2313.,45.,56.,-88.,74.,3*0.,-4310.,2308.,-1300.,8712
     C .,-3940.,-312.,-2417.,75.,-138.,-156.,3*0.,1520.,-2684.,29.,-2505.,2714.,
     D -1573.,-12.,-244.,-33.,114.,3*0.,86.,1212.,-1160.,-1104.,799.,-652.,5.,-15.,71.,
     E 111.,3*0.,-119.,1028.,609.,-272.,-124.,-116.,-1091.,141.,-56.,10.,3*0.,-540.,
     F -244.,-91.,22.,276.,-211.,-201.,58.,117.,4*0.,69.,-122.,58.,-170.,26.,236.,-25.,
     G -160.,64.,16.,3*0.,-220.,156.,51.,-35.,-18.,96.,121.,2.,-25.,15.,42*0. /
      DATA GT1 / 100., 2059.,-2907.,266.,-86.,255.,-70.,6*0.,-394.,602.,121.,-1003.,
     H 194.,-8.,99.,6*0.,-1369.,-1578.,-70.,163.,-117.,153.,85.,6*0.,649.,293.,-924.,
     I -130.,-54.,-42.,211.,6*0.,-177.,-154.,318.,-548.,-417.,-72.,157.,6*0.,304.,288.,
     J -186.,125.,80.,164.,-9.,6*0.,-139.,12.,153.,-73.,-6.,45.,6.,84*0./
      DATA GTT1 /1.,168*0./
      DATA G2 / 10., -304012.,-15401.,13071.,9493.,-2335.,492.,722.,85.,104.,-29.,
     A 2*0.,57782.,-21638.,29979.,-19889.,8035.,3557.,575.,-537.,65.,58.,-9.,
     B 2*0.,-19320.,2029.,15903.,12768.,5029.,2284.,-8.,79.,-93.,75.,-22.,2*0.,-4254.,
     C 2278.,-1338.,8812.,-3977.,-288.,-2383.,156.,-96.,-151.,8.,2*0.,1603.,-2743.,
     D 23.,-2466.,2665.,-1579.,-15.,-243.,-61.,121.,-28.,2*0.,51.,1178.,-1148.,-1089.,
     E 824.,-622.,-20.,-36.,55.,47.,64.,2*0.,-121.,1044.,566.,-234.,-148.,-133.,-1089.,
     F 155.,-81.,2.,47.,2*0.,-537.,-274.,-81.,70.,243.,-225.,-214.,36.,130.,16.,-2.,2*0.,
     G 54.,-117.,42.,-153.,46.,219.,-7.,-171.,74.,9.,18.,2*0.,-224.,138.,63.,-30.,-19.,
     H 90.,115.,1.,-15.,2.,20.,2*0.,-1.,45.,-10.,26.,-44.,-13.,-36.,40.,10.,-20.,11.,28*0./
      DATA GT2 / 100., 1403.,-2329.,-93.,145.,161.,-42.,-57.,35.,-10.,-1.,2*0.,-371.,
     I 876.,-9.,-1062.,90.,60.,82.,-34.,50.,-13.,-13.,2*0.,-1431.,-1662.,-456.,231.,
     J -175.,334.,82.,-144.,170.,-120.,88.,2*0.,520.,253.,-698.,-589.,66.,-4.,235.,-90.,
     K -11.,8.,-18.,2*0.,-219.,-14.,188.,-652.,-301.,-60.,83.,3.,34.,-8.,17.,2*0.,224.,
     L 159.,-261.,50.,-12.,176.,1.,-60.,-7.,-39.,-2.,2*0.,5.,9.,255.,-119.,33.,84.,23.,-17
     M .,43.,-36.,5.,2*0.,-96.,1.,43.,75.,-33.,49.,90.,-64.,-15.,47.,17.,2*0.,-50.,-21.,3.,
     N -79.,5.,10.,-36.,-43.,-42.,37.,16.,2*0.,66.,54.,3.,35.,-3.,-1.,45.,-5.,75.,-46.,31.,
     O 2*0.,-61.,-64.,2.,5.,-63.,-7.,7.,-3.,-2.,-45.,-23.,28*0./
      DATA GTT2 /1000.,-62.,-154.,-123.,1.,45.,-6.,-14.,6.,-5.,-3.,2*0.,-43.,114.,-18.,
     P-27.,-44.,1.,15.,-6.,8.,-1.,-3.,2*0.,54.,-16.,-253.,28.,17.,75.,10.,-34.,39.,-27.,20.,
     Q 2*0.,95.,-7.,79.,-183.,7.,8.,50.,-4.,-8.,5.,-8.,2*0.,4.,56.,-35.,-47.,-97.,15.,-11.,
     R -6.,15.,-7.,7.,2*0.,-46.,7.,-7.,1.,-24.,56.,26.,-27.,-2.,-6.,1.,2*0.,20.,-11.,15.,
     S -29.,29.,-10.,23.,-1.,5.,-9.,1.,2*0.,-14.,16.,14.,5.,-8.,16.,11.,-4.,-8.,6.,1.,2*0.,
     T -15.,-12.,5.,-11.,0.,-3.,-9.,-3.,-7.,5.,5.,2*0.,22.,7.,-2.,9.,6.,-1.,9.,-4.,19.,-9.,4.,
     U 2*0.,-12.,-14.,1.,1.,-11.,-1.,1.,-1.,1.,-6.,-2.,28*0./
      DATA G3 / 10., -304650.,-15414.,13258.,9591.,-2343.,491.,759.,74.,110.,-26.,
     A 23.,0.,57910.,-21633.,29763.,-19837.,8196.,3577.,545.,-524.,60.,66.,-20.,-18.,
     B 0.,-19772.,1566.,16075.,13169.,4864.,2339.,48.,80.,-81.,18.,10.,-21.,0.,-4453.,
     C 2334.,-949.,8420.,-3724.,-210.,-2491.,100.,-92.,-125.,-55.,55.,0.,1354.,-2667.,
     D 207.,-2415.,2562.,-1471.,17.,-367.,-8.,158.,-7.,-15.,0.,169.,1133.,-1287.,-1151
     E .,1303.,-452.,-37.,-83.,91.,17.,75.,24.,0.,-96.,1064.,568.,-272.,-149.,-43.,-916.,
     F 66.,-114.,26.,78.,-35.,0.,-579.,-250.,-8.,63.,95.,-117.,-376.,-227.,79.,87.,17.,
     G -13.,0.,101.,-130.,115.,-164.,55.,223.,-49.,-262.,351.,51.,-53.,25.,0.,-204.,144.,
     H 6.,-15.,14.,34.,148.,24.,-9.,-24.,13.,-12.,0.,11.,9.,-3.,75.,-23.,14.,-5.,43.,80.,
     I -137.,-27.,127.,0.,-8.,44.,-1.,-39.,-6.,18.,-32.,8.,-59.,-17.,105.,50.,14*0./
      DATA GT3 / 100.,2542.,-2390.,-559.,-62.,272.,-61.,-89.,61.,-24.,-1.,3.,0.,-466.,
     J 988.,350.,-1152.,-251.,48.,106.,-21.,-12.,30.,-9.,11.,0.,-707.,-1070.,-214.,-441
     K .,-122.,317.,62.,-108.,87.,4.,12.,5.,0.,848.,68.,-1489.,287.,-296.,-246.,396.,70.,
     L -33.,4.,19.,-30.,0.,345.,-39.,-87.,-652.,86.,-89.,-94.,107.,-14.,-40.,-20.,1.,0.,5.,
     M 300.,32.,311.,-635.,-315.,149.,96.,-85.,-28.,-2.,-34.,0.,-26.,-48.,258.,-80.,50.,
     N 82.,-167.,101.,99.,-57.,-43.,48.,0.,-87.,-46.,-102.,25.,188.,-243.,232.,523.,81.,
     O -132.,-33.,52.,0.,-15.,-10.,-122.,-26.,15.,-37.,29.,91.,-498.,-14.,103.,-19.,0.,
     P -38.,16.,67.,-14.,-83.,130.,-33.,-38.,99.,50.,22.,-3.,0.,21.,5.,54.,-26.,-30.,-3.,
     Q -39.,-2.,-104.,79.,46.,-165.,0.,35.,-26.,-17.,17.,18.,-50.,23.,-34.,37.,22.,-155.,
     R -40.,14*0./
      DATA GTT3 /1.,168*0./
      DATA G4 / 10.,-304708.,-15425.,13334.,9647.,-2375.,448.,793.,99.,96.,-17.,
     A 2*0.,57571.,-21702.,29893.,-19826.,8108.,3566.,594.,-516.,32.,93.,-22.,2*0.,
     B -19793.,2661.,15559.,12922.,5068.,2498.,-37.,-3.,-56.,31.,13.,2*0.,-4249.,
     C 2417.,-1740.,8336.,-3978.,-143.,-2324.,89.,-165.,-120.,16.,2*0.,1344.,-3037.,
     D 194.,-2764.,2247.,-1497.,96.,-335.,-33.,153.,-22.,2*0.,51.,1080.,-1073.,-1083.,
     E 1171.,-757.,20.,-33.,50.,7.,94.,2*0.,-76.,1181.,583.,-181.,-270.,1.,-831.,100.,
     F -120.,8.,87.,2*0.,-544.,-212.,-87.,55.,151.,-236.,-278.,39.,102.,4.,3.,2*0.,98.,
     G -162.,99.,-189.,106.,206.,-2.,-207.,187.,62.,-24.,2*0.,-254.,128.,31.,-25.,-21.,
     H 73.,127.,47.,7.,-38.,-1.,2*0.,29.,35.,-7.,66.,-50.,10.,-28.,21.,42.,-88.,53.,28*0./
      DATA GT4 / 100.,2682.,-2366.,-724.,-157.,359.,12.,-160.,19.,17.,-3.,2*0.,225.,
     I 1003.,150.,-1142.,-118.,58.,38.,-26.,27.,-8.,-8.,2*0.,-684.,-2832.,792.,84.,
     J -536.,-27.,235.,72.,33.,-46.,17.,2*0.,449.,-96.,177.,327.,102.,-326.,128.,86.,83.,
     K -9.,-87.,2*0.,369.,564.,-109.,-205.,834.,-108.,-277.,84.,42.,-37.,-12.,2*0.,234.,
     L 401.,-424.,63.,-503.,504.,8.,-57.,0.,-3.,-33.,2*0.,-65.,-238.,249.,-170.,234.,
     M -259.,-130.,101.,49.,-48.,-33.,2*0.,-168.,-114.,58.,123.,94.,40.,60.,-140.,73.,
     N 54.,-21.,2*0.,1.,39.,-106.,-9.,-49.,56.,-67.,-8.,-148.,-13.,27.,2*0.,48.,42.,17.,
     O -41.,-22.,21.,1.,-113.,16.,33.,49.,2*0.,-14.,-37.,51.,-2.,4.,-19.,7.,40.,-53.,31.,
     P -75.,28*0./
      DATA GTT4 /1.,168*0./
      DATA G5 / 1., -30339.,-1654.,1297.,958.,-223.,47.,71.,10.,4*0.,5758.,-2123.,
     A 2994.,-2036.,805.,357.,60.,-54.,9.,4*0.,-2006.,130.,1567.,1289.,492.,246.,4.,0.,
     B -3.,4*0.,-403.,242.,-176.,843.,-392.,-26.,-229.,12.,-12.,4*0.,149.,-280.,8.,-265
     C .,256.,-161.,3.,-25.,-4.,4*0.,16.,125.,-123.,-107.,77.,-51.,-4.,-9.,7.,4*0.,-14.,
     D 106.,68.,-32.,-10.,-13.,-112.,13.,-5.,4*0.,-57.,-27.,-8.,9.,23.,-19.,-17.,-2.,12.,
     E 4*0.,3.,-13.,5.,-17.,4.,22.,-3.,-16.,6.,56*0./
      DATA GT5 / 10., 153.,-244.,2.,-7.,19.,-1.,-5.,1.,4*0.,-23.,87.,3.,-108.,2.,11.,-3.,
     F -3.,4.,4*0.,-118.,-167.,-16.,7.,-30.,29.,11.,-7.,6.,4*0.,42.,7.,-77.,-38.,-1.,6.,19.,
     G -5.,5*0.,-1.,16.,29.,-42.,-21.,0.,-4.,3.,5*0.,23.,17.,-24.,8.,-3.,13.,-4.,0.,-1.,4*0.,
     H-9.,-4.,20.,-11.,1.,9.,-2.,-2.,3.,4*0.,-11.,3.,4.,2.,4.,2.,3.,-6.,-3.,4*0.,1.,-2.,-3.,-2.,
     I -3.,-4.,-3.,-3.,-5.,56*0./
      DATA GTT5 /1.,168*0./
      DATA G6 / 1., -30375.,-1648.,1164.,930.,-179.,42.,77.,11.,4*0.,5769.,-2087.,
     A 2954.,-2033.,811.,357.,55.,-56.,23.,4*0.,-1995.,116.,1579.,1299.,490.,248.,12.,
     B 8.,-6.,4*0.,-389.,230.,-141.,880.,-402.,-20.,-239.,5.,-17.,4*0.,142.,-276.,5.,
     C -264.,262.,-171.,16.,-35.,5.,4*0.,30.,135.,-123.,-100.,84.,-64.,8.,-16.,20.,4*0.,
     D -18.,101.,60.,-32.,-27.,-12.,-110.,9.,-1.,4*0.,-47.,-35.,-9.,2.,27.,-17.,-24.,2.,
     E 12.,4*0.,5.,-7.,3.,-20.,8.,26.,10.,-12.,7.,56*0./
      DATA GT6 / 10., 155.,-266.,0.,6.,8.,7*0.,6.,83.,-13.,-95.,10.,4.,-5.,6*0.,-114.,
     F -182.,13.,-19.,-22.,16.,18.,6*0.,32.,16.,-85.,-6.,2.,-3.,14.,6*0.,30.,-7.,27.,-27.,
     G -30.,-11.,6.,6*0.,19.,23.,-18.,14.,5.,17.,2.,6*0.,-22.,2.,9.,-21.,-1.,-2.,-22.,84*0./
      DATA GTT6 /1.,168*0./
      DATA G7/10.,-302059.,-17917.,12899.,9475.,-2145.,460.,734.,121.,107.,-39.,16.,
     A -4.,57446.,-20664.,29971.,-20708.,8009.,3595.,651.,-546.,77.,57.,-26.,-31.,30.,
     B -20582.,430.,16086.,12760.,4579.,2490.,95.,46.,-32.,23.,7.,-36.,5.,-3699.,2456.,
     C -1880.,8334.,-3960.,-290.,-2188.,175.,-124.,-110.,-19.,37.,-3.,1617.,-2758.,
     D 185.,-2788.,2436.,-1669.,20.,-210.,-44.,131.,-15.,-3.,-13.,157.,1420.,-1310.,
     E -911.,808.,-582.,-22.,-32.,45.,33.,74.,-6.,4.,-171.,1146.,625.,-323.,-78.,38.,
     F -1125.,143.,34.,2.,46.,-8.,-14.,-666.,-265.,-34.,81.,209.,-240.,-186.,41.,125.,
     G 15.,6.,1.,-12.,121.,-160.,22.,-176.,46.,189.,-46.,-187.,94.,9.,-8.,2.,-12.,-174.,
     H 163.,14.,-27.,-32.,80.,137.,-4.,-14.,-4.,22.,-24.,-1.,27.,19.,0.,35.,-45.,22.,-31.,
     I 56.,-1.,-63.,14.,4.,10.,-2.,26.,-26.,-9.,21.,-1.,18.,-14.,-28.,-17.,-14.,6.,-4.,-3.,
     J 4.,9.,-1.,-10.,26.,-32.,13.,-6.,-19.,7.,19.,12./
      DATA GT7/10.,231.,-244.,-19.,-7.,12.,-7.,0.,3.,4*0.,-46.,112.,-1.,-90.,-6.,7.,6.,
     K -3.,3.,4*0.,-104.,-166.,40.,-20.,-36.,12.,14.,3.,4.,4*0.,72.,21.,-52.,-54.,-11.,0.,
     L 17.,6.,1.,4*0.,22.,-5.,14.,-24.,-23.,-15.,6.,3.,-1.,4*0.,1.,25.,-14.,9.,1.,11.,-3.,2.,
     M -3.,4*0.,-5.,11.,2.,-3.,7.,22.,-5.,1.,9.,4*0.,-17.,-3.,7.,1.,-2.,-3.,-2.,-1.,-2.,4*0.,
     N 2.,-6.,-3.,-4.,1.,-2.,-2.,-1.,6.,56*0./
      DATA GTT7 /1.,168*0./

C  *****  NON-SUBSCRIPTED, FIXED-INDEX VERSION BEGINS HERE (NO DO-LOOPS)
C  *****  BEGIN PROGRAM
      IF(SHMIT(1,1).EQ.-1.)   GO TO 8
C  *****  INITIALIZE * ONCE ONLY, FIRST TIME SUBROUTINE IS CALLED
      SHMIT(1,1)=-1.
      DO 2 N=2,13
      SHMIT(N,1) = (2*N-3) * SHMIT(N-1,1) / (N-1)
      JJ=2
      DO 2 M=2,N
      SHMIT(N,M) = SHMIT(N,M-1) * SQRT(FLOAT((N-M+1)*JJ)/(N+M-2))
      SHMIT(M-1,N)=SHMIT(N,M)
    2 JJ = 1
      DO 7 K=1,7
      F1=RLG(1,1,K)
      F2=RLGT(1,1,K)
      F3=RLGTT(1,1,K)
      NMAX=NMX(K)
      L = 0
      DO 3 I=1,3
    3 RISUM(K,I) = 0.
      DO 4 N=1,NMAX
      DO 4 M=1,NMAX
      L = L+1
      RISUM(K,1)=RISUM(K,1)+L*RLG(N,M,K)
      RISUM(K,2)=RISUM(K,2)+L*RLGT(N,M,K)
    4 RISUM(K,3)=RISUM(K,3)+L*RLGTT(N,M,K)
      DO 6 I=1,3
      IF(RISUM(K,I).EQ.RLSUM(K,I))  GO TO 6
C  *****  ERROR IN DATA CARDS - NOTE WRITE AND STOP STATEMENTS
      WRITE(*,5) K,I,RLSUM(K,I),RISUM(K,I)
    5 FORMAT(///29H DATA WRONG IN ALLMAG--MODEL ,I2,3X,2HI=,I1,3X,
     A17HPRECALCULATED SUM,I10,3X,17HTHIS MACHINE GETS,I10)
      STOP
    6 CONTINUE
      DO 7 N=1,NMAX
      DO 7 M=1,NMAX
      GG(N,M,K)=RLG(N,M,K)*SHMIT(N,M)/F1
      GGT(N,M,K)=RLGT(N,M,K)*SHMIT(N,M)/F2
    7 GGTT(N,M,K)=RLGTT(N,M,K)*SHMIT(N,M)/F3
    8 IF((MODEL.EQ.MODOLD).AND.(TM.EQ.TMOLD))  GO TO 11
      IF(MODEL.LT.1.OR.MODEL.GT.7) STOP

C  *****  NOTE WRITE STATEMENT - NEW MODEL OR NEW TIME
C      IF(MODEL.EQ.1) WRITE(6,21) TM
C      IF(MODEL.EQ.2) WRITE(6,22) TM
C      IF(MODEL.EQ.3) WRITE(6,23) TM
C      IF(MODEL.EQ.4) WRITE(6,24) TM
C      IF(MODEL.EQ.5) WRITE(6,25) TM
C      IF(MODEL.EQ.6) WRITE(6,26) TM
C      IF(MODEL.EQ.7) WRITE(6,27) TM
C   21 FORMAT(1H0,20X,41HMODEL 1 HENDRICKS+CAIN GSFC 9/65 FOR TM =F9.3//)
C   22 FORMAT(1H0,20X,41HMODEL 2 (CAIN ET AL GSFC 12/66)  FOR TM =F9.3//)
C   23 FORMAT(1H0,20X,41HMODEL 3 (CAIN+LANGEL POGO 10/68) FOR TM =F9.3//)
C   24 FORMAT(1H0,20X,41HMODEL 4 (CAIN+SWEENEY POGO 8/69) FOR TM =F9.3//)
C   25 FORMAT(1H0,20X,41HMODEL 5    (IGRF 1965.0)         FOR TM =F9.3//)
C   26 FORMAT(1H0,20X,41HMODEL 6 LEATON MALIN EVANS 1965  FOR TM =F9.3//)
C   27 FORMAT(1H0,20X,41HMODEL 7  (HURWITZ USC+GS 1970)   FOR TM =F9.3//)

      MODOLD=MODEL
      TMOLD=TM
      NMAX=NMX(MODEL)
      T=TM-T0(MODEL)
      DO 10 N=1,NMAX
      DO 10 M=1,NMAX
   10 G(N,M)=GG(N,M,MODEL)+T*(GGT(N,M,MODEL)+GGTT(N,M,MODEL)*T)
C *** THE NEXT TWO CARDS SHOULD COMPLY WITH THE SELECTED PRECISION MODE
      WLONG = -RAD*ATAN(G(1,2)/G(2,2))
      COLAT = RAD*ATAN(SQRT(G(1,2)**2+G(2,2)**2)/G(2,1))
C      PRINT 19, WLONG,COLAT
C   19 FORMAT(~0GEOGRAPHIC COORDINATES OF BOREAL MAGNETIC DIPOLE POLE:
C     $WEST LONGITUDE =~,F9.3,~,GEOC. COLATITUDE =~,F7.3/)

C  *****  CALCULATION USUALLY BEGINS HERE
   11 P21=CT
      P22=ST
      AR=6371.2/RKM
      SP2=SPH
      CP2=CPH
      DP21=-P22
      DP22=P21
      AOR=AR*AR*AR
      C2=G(2,2)*CP2+G(1,2)*SP2
      BR=-(AOR+AOR)*(G(2,1)*P21+C2*P22)
      BT=AOR*(G(2,1)*DP21+C2*DP22)
      BP=AOR*(G(1,2)*CP2-G(2,2)*SP2)*P22
      IF (NMAX.LE. 2) GO TO 1
C                                                           N= 3
      SP3=(SP2+SP2)*CP2
      CP3=(CP2+SP2)*(CP2-SP2)
      P31=P21*P21-0.333333333
      P32=P21*P22
      P33=P22*P22
      DP31=-P32-P32
      DP32=P21*P21-P33
      DP33=-DP31
      AOR=AOR*AR
      C2=G(3,2)*CP2+G(1,3)*SP2
      C3=G(3,3)*CP3+G(2,3)*SP3
      BR=BR-3.0*AOR*(G(3,1)*P31+C2*P32+C3*P33)
      BT=BT+AOR*(G(3,1)*DP31+C2*DP32+C3*DP33)
      BP=BP-AOR*((G(3,2)*SP2-G(1,3)*CP2)*P32+2.0*(G(3,3)*SP3-G(2,3)*CP3)
     1*P33)
      IF (NMAX.LE. 3) GO TO 1
C                                                           N= 4
      SP4=SP2*CP3+CP2*SP3
      CP4=CP2*CP3-SP2*SP3
      P41=P21*P31-0.26666666*P21
      DP41=P21*DP31+DP21*P31-0.26666666*DP21
      P42=P21*P32-0.20000000*P22
      DP42=P21*DP32+DP21*P32-0.20000000*DP22
      P43=P21*P33
      DP43=P21*DP33+DP21*P33
      P44=P22*P33
      DP44=3.0*P43
      AOR=AOR*AR
      C2=G(4,2)*CP2+G(1,4)*SP2
      C3=G(4,3)*CP3+G(2,4)*SP3
      C4=G(4,4)*CP4+G(3,4)*SP4
      BR=BR-4.0*AOR*(G(4,1)*P41+C2*P42+C3*P43+C4*P44)
      BT=BT+AOR*(G(4,1)*DP41+C2*DP42+C3*DP43+C4*DP44)
      BP=BP-AOR*((G(4,2)*SP2-G(1,4)*CP2)*P42+2.0*(G(4,3)*SP3-G(2,4)*CP3)
     1*P43+3.0*(G(4,4)*SP4-G(3,4)*CP4)*P44)
      IF (NMAX.LE. 4) GO TO 1
C                                                           N= 5
      SP5=(SP3+SP3)*CP3
      CP5=(CP3+SP3)*(CP3-SP3)
      P51=P21*P41-0.25714285*P31
      DP51=P21*DP41+DP21*P41-0.25714285*DP31
      P52=P21*P42-0.22857142*P32
      DP52=P21*DP42+DP21*P42-0.22857142*DP32
      P53=P21*P43-0.14285714*P33
      DP53=P21*DP43+DP21*P43-0.14285714*DP33
      P54=P21*P44
      DP54=P21*DP44+DP21*P44
      P55=P22*P44
      DP55=4.0*P54
      AOR=AOR*AR
      C2=G(5,2)*CP2+G(1,5)*SP2
      C3=G(5,3)*CP3+G(2,5)*SP3
      C4=G(5,4)*CP4+G(3,5)*SP4
      C5=G(5,5)*CP5+G(4,5)*SP5
      BR=BR-5.0*AOR*(G(5,1)*P51+C2*P52+C3*P53+C4*P54+C5*P55)
      BT=BT+AOR*(G(5,1)*DP51+C2*DP52+C3*DP53+C4*DP54+C5*DP55)
      BP=BP-AOR*((G(5,2)*SP2-G(1,5)*CP2)*P52+2.0*(G(5,3)*SP3-G(2,5)*CP3)
     1*P53+3.0*(G(5,4)*SP4-G(3,5)*CP4)*P54+4.0*(G(5,5)*SP5-G(4,5)*CP5)*P
     255)
      IF (NMAX.LE. 5) GO TO 1
C                                                           N= 6
      SP6=SP2*CP5+CP2*SP5
      CP6=CP2*CP5-SP2*SP5
      P61=P21*P51-0.25396825*P41
      DP61=P21*DP51+DP21*P51-0.25396825*DP41
      P62=P21*P52-0.23809523*P42
      DP62=P21*DP52+DP21*P52-0.23809523*DP42
      P63=P21*P53-0.19047619*P43
      DP63=P21*DP53+DP21*P53-0.19047619*DP43
      P64=P21*P54-0.11111111*P44
      DP64=P21*DP54+DP21*P54-0.11111111*DP44
      P65=P21*P55
      DP65=P21*DP55+DP21*P55
      P66=P22*P55
      DP66=5.0*P65
      AOR=AOR*AR
      C2=G(6,2)*CP2+G(1,6)*SP2
      C3=G(6,3)*CP3+G(2,6)*SP3
      C4=G(6,4)*CP4+G(3,6)*SP4
      C5=G(6,5)*CP5+G(4,6)*SP5
      C6=G(6,6)*CP6+G(5,6)*SP6
      BR=BR-6.0*AOR*(G(6,1)*P61+C2*P62+C3*P63+C4*P64+C5*P65+C6*P66)
      BT=BT+AOR*(G(6,1)*DP61+C2*DP62+C3*DP63+C4*DP64+C5*DP65+C6*DP66)
      BP=BP-AOR*((G(6,2)*SP2-G(1,6)*CP2)*P62+2.0*(G(6,3)*SP3-G(2,6)*CP3)
     1*P63+3.0*(G(6,4)*SP4-G(3,6)*CP4)*P64+4.0*(G(6,5)*SP5-G(4,6)*CP5)*P
     265+5.0*(G(6,6)*SP6-G(5,6)*CP6)*P66)
      IF (NMAX.LE. 6) GO TO 1
C                                                           N= 7
      SP7=(SP4+SP4)*CP4
      CP7=(CP4+SP4)*(CP4-SP4)
      P71=P21*P61-0.25252525*P51
      DP71=P21*DP61+DP21*P61-0.25252525*DP51
      P72=P21*P62-0.24242424*P52
      DP72=P21*DP62+DP21*P62-0.24242424*DP52
      P73=P21*P63-0.21212121*P53
      DP73=P21*DP63+DP21*P63-0.21212121*DP53
      P74=P21*P64-0.16161616*P54
      DP74=P21*DP64+DP21*P64-0.16161616*DP54
      P75=P21*P65-0.09090909*P55
      DP75=P21*DP65+DP21*P65-0.09090909*DP55
      P76=P21*P66
      DP76=P21*DP66+DP21*P66
      P77=P22*P66
      DP77=6.0*P76
      AOR=AOR*AR
      C2=G(7,2)*CP2+G(1,7)*SP2
      C3=G(7,3)*CP3+G(2,7)*SP3
      C4=G(7,4)*CP4+G(3,7)*SP4
      C5=G(7,5)*CP5+G(4,7)*SP5
      C6=G(7,6)*CP6+G(5,7)*SP6
      C7=G(7,7)*CP7+G(6,7)*SP7
      BR=BR-7.0*AOR*(G(7,1)*P71+C2*P72+C3*P73+C4*P74+C5*P75+C6*P76+C7*P7
     17)
      BT=BT+AOR*(G(7,1)*DP71+C2*DP72+C3*DP73+C4*DP74+C5*DP75+C6*DP76+C7*
     1DP77)
      BP=BP-AOR*((G(7,2)*SP2-G(1,7)*CP2)*P72+2.0*(G(7,3)*SP3-G(2,7)*CP3)
     1*P73+3.0*(G(7,4)*SP4-G(3,7)*CP4)*P74+4.0*(G(7,5)*SP5-G(4,7)*CP5)*P
     275+5.0*(G(7,6)*SP6-G(5,7)*CP6)*P76+6.0*(G(7,7)*SP7-G(6,7)*CP7)*P77
     3)
      IF (NMAX.LE. 7) GO TO 1
C                                                           N= 8
      SP8=SP2*CP7+CP2*SP7
      CP8=CP2*CP7-SP2*SP7
      P81=P21*P71-0.25174825*P61
      DP81=P21*DP71+DP21*P71-0.25174825*DP61
      P82=P21*P72-0.24475524*P62
      DP82=P21*DP72+DP21*P72-0.24475524*DP62
      P83=P21*P73-0.22377622*P63
      DP83=P21*DP73+DP21*P73-0.22377622*DP63
      P84=P21*P74-0.18881118*P64
      DP84=P21*DP74+DP21*P74-0.18881118*DP64
      P85=P21*P75-0.13986013*P65
      DP85=P21*DP75+DP21*P75-0.13986013*DP65
      P86=P21*P76-0.07692307*P66
      DP86=P21*DP76+DP21*P76-0.07692307*DP66
      P87=P21*P77
      DP87=P21*DP77+DP21*P77
      P88=P22*P77
      DP88=7.0*P87
      AOR=AOR*AR
      C2=G(8,2)*CP2+G(1,8)*SP2
      C3=G(8,3)*CP3+G(2,8)*SP3
      C4=G(8,4)*CP4+G(3,8)*SP4
      C5=G(8,5)*CP5+G(4,8)*SP5
      C6=G(8,6)*CP6+G(5,8)*SP6
      C7=G(8,7)*CP7+G(6,8)*SP7
      C8=G(8,8)*CP8+G(7,8)*SP8
      BR=BR-8.0*AOR*(G(8,1)*P81+C2*P82+C3*P83+C4*P84+C5*P85+C6*P86+C7*P8
     17+C8*P88)
      BT=BT+AOR*(G(8,1)*DP81+C2*DP82+C3*DP83+C4*DP84+C5*DP85+C6*DP86+C7*
     1DP87+C8*DP88)
      BP=BP-AOR*((G(8,2)*SP2-G(1,8)*CP2)*P82+2.0*(G(8,3)*SP3-G(2,8)*CP3)
     1*P83+3.0*(G(8,4)*SP4-G(3,8)*CP4)*P84+4.0*(G(8,5)*SP5-G(4,8)*CP5)*P
     285+5.0*(G(8,6)*SP6-G(5,8)*CP6)*P86+6.0*(G(8,7)*SP7-G(6,8)*CP7)*P87
     3+7.0*(G(8,8)*SP8-G(7,8)*CP8)*P88)
      IF (NMAX.LE. 8) GO TO 1
                                                           N= 9
      SP9=(SP5+SP5)*CP5
      CP9=(CP5+SP5)*(CP5-SP5)
      P91=P21*P81-0.25128205*P71
      DP91=P21*DP81+DP21*P81-0.25128205*DP71
      P92=P21*P82-0.24615384*P72
      DP92=P21*DP82+DP21*P82-0.24615384*DP72
      P93=P21*P83-0.23076923*P73
      DP93=P21*DP83+DP21*P83-0.23076923*DP73
      P94=P21*P84-0.20512820*P74
      DP94=P21*DP84+DP21*P84-0.20512820*DP74
      P95=P21*P85-0.16923076*P75
      DP95=P21*DP85+DP21*P85-0.16923076*DP75
      P96=P21*P86-0.12307692*P76
      DP96=P21*DP86+DP21*P86-0.12307692*DP76
      P97=P21*P87-0.06666666*P77
      DP97=P21*DP87+DP21*P87-0.06666666*DP77
      P98=P21*P88
      DP98=P21*DP88+DP21*P88
      P99=P22*P88
      DP99=8.0*P98
      AOR=AOR*AR
      C2=G(9,2)*CP2+G(1,9)*SP2
      C3=G(9,3)*CP3+G(2,9)*SP3
      C4=G(9,4)*CP4+G(3,9)*SP4
      C5=G(9,5)*CP5+G(4,9)*SP5
      C6=G(9,6)*CP6+G(5,9)*SP6
      C7=G(9,7)*CP7+G(6,9)*SP7
      C8=G(9,8)*CP8+G(7,9)*SP8
      C9=G(9,9)*CP9+G(8,9)*SP9
      BR=BR-9.0*AOR*(G(9,1)*P91+C2*P92+C3*P93+C4*P94+C5*P95+C6*P96+C7*P9
     17+C8*P98+C9*P99)
      BT=BT+AOR*(G(9,1)*DP91+C2*DP92+C3*DP93+C4*DP94+C5*DP95+C6*DP96+C7*
     1DP97+C8*DP98+C9*DP99)
      BP=BP-AOR*((G(9,2)*SP2-G(1,9)*CP2)*P92+2.0*(G(9,3)*SP3-G(2,9)*CP3)
     1*P93+3.0*(G(9,4)*SP4-G(3,9)*CP4)*P94+4.0*(G(9,5)*SP5-G(4,9)*CP5)*P
     295+5.0*(G(9,6)*SP6-G(5,9)*CP6)*P96+6.0*(G(9,7)*SP7-G(6,9)*CP7)*P97
     3+7.0*(G(9,8)*SP8-G(7,9)*CP8)*P98+8.0*(G(9,9)*SP9-G(8,9)*CP9)*P99)
      IF (NMAX.LE. 9) GO TO 1
                                                           N=10
      SP10=SP2*CP9+CP2*SP9
      CP10=CP2*CP9-SP2*SP9
      P101=P21*P91-0.25098039*P81
      DP101=P21*DP91+DP21*P91-0.25098039*DP81
      P102=P21*P92-0.24705882*P82
      DP102=P21*DP92+DP21*P92-0.24705882*DP82
      P103=P21*P93-0.23529411*P83
      DP103=P21*DP93+DP21*P93-0.23529411*DP83
      P104=P21*P94-0.21568627*P84
      DP104=P21*DP94+DP21*P94-0.21568627*DP84
      P105=P21*P95-0.18823529*P85
      DP105=P21*DP95+DP21*P95-0.18823529*DP85
      P106=P21*P96-0.15294117*P86
      DP106=P21*DP96+DP21*P96-0.15294117*DP86
      P107=P21*P97-0.10980392*P87
      DP107=P21*DP97+DP21*P97-0.10980392*DP87
      P108=P21*P98-0.05882352*P88
      DP108=P21*DP98+DP21*P98-0.05882352*DP88
      P109=P21*P99
      DP109=P21*DP99+DP21*P99
      P1010=P22*P99
      DP1010=9.0*P109
      AOR=AOR*AR
      C2=G(10,2)*CP2+G(1,10)*SP2
      C3=G(10,3)*CP3+G(2,10)*SP3
      C4=G(10,4)*CP4+G(3,10)*SP4
      C5=G(10,5)*CP5+G(4,10)*SP5
      C6=G(10,6)*CP6+G(5,10)*SP6
      C7=G(10,7)*CP7+G(6,10)*SP7
      C8=G(10,8)*CP8+G(7,10)*SP8
      C9=G(10,9)*CP9+G(8,10)*SP9
      C10=G(10,10)*CP10+G(9,10)*SP10
      BR=BR-10.0*AOR*(G(10,1)*P101+C2*P102+C3*P103+C4*P104+C5*P105+C6*P1
     106+C7*P107+C8*P108+C9*P109+C10*P1010)
      BT=BT+AOR*(G(10,1)*DP101+C2*DP102+C3*DP103+C4*DP104+C5*DP105+C6*DP
     1106+C7*DP107+C8*DP108+C9*DP109+C10*DP1010)
      BP=BP-AOR*((G(10,2)*SP2-G(1,10)*CP2)*P102+2.0*(G(10,3)*SP3-G(2,10)
     1*CP3)*P103+3.0*(G(10,4)*SP4-G(3,10)*CP4)*P104+4.0*(G(10,5)*SP5-G(4
     2,10)*CP5)*P105+5.0*(G(10,6)*SP6-G(5,10)*CP6)*P106+6.0*(G(10,7)*SP7
     3-G(6,10)*CP7)*P107+7.0*(G(10,8)*SP8-G(7,10)*CP8)*P108+8.0*(G(10,9)
     4*SP9-G(8,10)*CP9)*P109+9.0*(G(10,10)*SP10-G(9,10)*CP10)*P1010)
      IF (NMAX.LE.10) GO TO 1
                                                           N=11
      SP11=(SP6+SP6)*CP6
      CP11=(CP6+SP6)*(CP6-SP6)
      P111=P21*P101-0.25077399*P91
      DP111=P21*DP101+DP21*P101-0.25077399*DP91
      P112=P21*P102-0.24767801*P92
      DP112=P21*DP102+DP21*P102-0.24767801*DP92
      P113=P21*P103-0.23839009*P93
      DP113=P21*DP103+DP21*P103-0.23839009*DP93
      P114=P21*P104-0.22291021*P94
      DP114=P21*DP104+DP21*P104-0.22291021*DP94
      P115=P21*P105-0.20123839*P95
      DP115=P21*DP105+DP21*P105-0.20123839*DP95
      P116=P21*P106-0.17337461*P96
      DP116=P21*DP106+DP21*P106-0.17337461*DP96
      P117=P21*P107-0.13931888*P97
      DP117=P21*DP107+DP21*P107-0.13931888*DP97
      P118=P21*P108-0.09907120*P98
      DP118=P21*DP108+DP21*P108-0.09907120*DP98
      P119=P21*P109-0.05263157*P99
      DP119=P21*DP109+DP21*P109-0.05263157*DP99
      P1110=P21*P1010
      DP1110=P21*DP1010+DP21*P1010
      P1111=P22*P1010
      DP1111=10.0*P1110
      AOR=AOR*AR
      C2=G(11,2)*CP2+G(1,11)*SP2
      C3=G(11,3)*CP3+G(2,11)*SP3
      C4=G(11,4)*CP4+G(3,11)*SP4
      C5=G(11,5)*CP5+G(4,11)*SP5
      C6=G(11,6)*CP6+G(5,11)*SP6
      C7=G(11,7)*CP7+G(6,11)*SP7
      C8=G(11,8)*CP8+G(7,11)*SP8
      C9=G(11,9)*CP9+G(8,11)*SP9
      C10=G(11,10)*CP10+G(9,11)*SP10
      C11=G(11,11)*CP11+G(10,11)*SP11
      BR=BR-11.0*AOR*(G(11,1)*P111+C2*P112+C3*P113+C4*P114+C5*P115+C6*P1
     116+C7*P117+C8*P118+C9*P119+C10*P1110+C11*P1111)
      BT=BT+AOR*(G(11,1)*DP111+C2*DP112+C3*DP113+C4*DP114+C5*DP115+C6*DP
     1116+C7*DP117+C8*DP118+C9*DP119+C10*DP1110+C11*DP1111)
      BP=BP-AOR*((G(11,2)*SP2-G(1,11)*CP2)*P112+2.0*(G(11,3)*SP3-G(2,11)
     1*CP3)*P113+3.0*(G(11,4)*SP4-G(3,11)*CP4)*P114+4.0*(G(11,5)*SP5-G(4
     2,11)*CP5)*P115+5.0*(G(11,6)*SP6-G(5,11)*CP6)*P116+6.0*(G(11,7)*SP7
     3-G(6,11)*CP7)*P117+7.0*(G(11,8)*SP8-G(7,11)*CP8)*P118+8.0*(G(11,9)
     4*SP9-G(8,11)*CP9)*P119+9.0*(G(11,10)*SP10-G(9,11)*CP10)*P1110+10.0
     5*(G(11,11)*SP11-G(10,11)*CP11)*P1111)
      IF (NMAX.LE.11) GO TO 1
                                                           N=12
      SP12=SP2*CP11+CP2*SP11
      CP12=CP2*CP11-SP2*SP11
      P121=P21*P111-0.25062656*P101
      DP121=P21*DP111+DP21*P111-0.25062656*DP101
      P122=P21*P112-0.24812030*P102
      DP122=P21*DP112+DP21*P112-0.24812030*DP102
      P123=P21*P113-0.24060150*P103
      DP123=P21*DP113+DP21*P113-0.24060150*DP103
      P124=P21*P114-0.22807017*P104
      DP124=P21*DP114+DP21*P114-0.22807017*DP104
      P125=P21*P115-0.21052631*P105
      DP125=P21*DP115+DP21*P115-0.21052631*DP105
      P126=P21*P116-0.18796992*P106
      DP126=P21*DP116+DP21*P116-0.18796992*DP106
      P127=P21*P117-0.16040100*P107
      DP127=P21*DP117+DP21*P117-0.16040100*DP107
      P128=P21*P118-0.12781954*P108
      DP128=P21*DP118+DP21*P118-0.12781954*DP108
      P129=P21*P119-0.09022556*P109
      DP129=P21*DP119+DP21*P119-0.09022556*DP109
      P1210=P21*P1110-0.04761904*P1010
      DP1210=P21*DP1110+DP21*P1110-0.04761904*DP1010
      P1211=P21*P1111
      DP1211=P21*DP1111+DP21*P1111
      P1212=P22*P1111
      DP1212=11.0*P1211
      AOR=AOR*AR
      C2=G(12,2)*CP2+G(1,12)*SP2
      C3=G(12,3)*CP3+G(2,12)*SP3
      C4=G(12,4)*CP4+G(3,12)*SP4
      C5=G(12,5)*CP5+G(4,12)*SP5
      C6=G(12,6)*CP6+G(5,12)*SP6
      C7=G(12,7)*CP7+G(6,12)*SP7
      C8=G(12,8)*CP8+G(7,12)*SP8
      C9=G(12,9)*CP9+G(8,12)*SP9
      C10=G(12,10)*CP10+G(9,12)*SP10
      C11=G(12,11)*CP11+G(10,12)*SP11
      C12=G(12,12)*CP12+G(11,12)*SP12
      BR=BR-12.0*AOR*(G(12,1)*P121+C2*P122+C3*P123+C4*P124+C5*P125+C6*P1
     126+C7*P127+C8*P128+C9*P129+C10*P1210+C11*P1211+C12*P1212)
      BT=BT+AOR*(G(12,1)*DP121+C2*DP122+C3*DP123+C4*DP124+C5*DP125+C6*DP
     1126+C7*DP127+C8*DP128+C9*DP129+C10*DP1210+C11*DP1211+C12*DP1212)
      BP=BP-AOR*((G(12,2)*SP2-G(1,12)*CP2)*P122+2.0*(G(12,3)*SP3-G(2,12)
     1*CP3)*P123+3.0*(G(12,4)*SP4-G(3,12)*CP4)*P124+4.0*(G(12,5)*SP5-G(4
     2,12)*CP5)*P125+5.0*(G(12,6)*SP6-G(5,12)*CP6)*P126+6.0*(G(12,7)*SP7
     3-G(6,12)*CP7)*P127+7.0*(G(12,8)*SP8-G(7,12)*CP8)*P128+8.0*(G(12,9)
     4*SP9-G(8,12)*CP9)*P129+9.0*(G(12,10)*SP10-G(9,12)*CP10)*P1210+10.0
     5*(G(12,11)*SP11-G(10,12)*CP11)*P1211+11.0*(G(12,12)*SP12-G(11,12)*
     6CP12)*P1212)
      IF (NMAX.LE.12) GO TO 1
                                                           N=13
      SP13=(SP7+SP7)*CP7
      CP13=(CP7+SP7)*(CP7-SP7)
      P131=P21*P121-0.25051759*P111
      DP131=P21*DP121+DP21*P121-0.25051759*DP111
      P132=P21*P122-0.24844720*P112
      DP132=P21*DP122+DP21*P122-0.24844720*DP112
      P133=P21*P123-0.24223602*P113
      DP133=P21*DP123+DP21*P123-0.24223602*DP113
      P134=P21*P124-0.23188405*P114
      DP134=P21*DP124+DP21*P124-0.23188405*DP114
      P135=P21*P125-0.21739130*P115
      DP135=P21*DP125+DP21*P125-0.21739130*DP115
      P136=P21*P126-0.19875776*P116
      DP136=P21*DP126+DP21*P126-0.19875776*DP116
      P137=P21*P127-0.17598343*P117
      DP137=P21*DP127+DP21*P127-0.17598343*DP117
      P138=P21*P128-0.14906832*P118
      DP138=P21*DP128+DP21*P128-0.14906832*DP118
      P139=P21*P129-0.11801242*P119
      DP139=P21*DP129+DP21*P129-0.11801242*DP119
      P1310=P21*P1210-0.08281573*P1110
      DP1310=P21*DP1210+DP21*P1210-0.08281573*DP1110
      P1311=P21*P1211-0.04347826*P1111
      DP1311=P21*DP1211+DP21*P1211-0.04347826*DP1111
      P1312=P21*P1212
      DP1312=P21*DP1212+DP21*P1212
      P1313=P22*P1212
      DP1313=12.0*P1312
      AOR=AOR*AR
      C2=G(13,2)*CP2+G(1,13)*SP2
      C3=G(13,3)*CP3+G(2,13)*SP3
      C4=G(13,4)*CP4+G(3,13)*SP4
      C5=G(13,5)*CP5+G(4,13)*SP5
      C6=G(13,6)*CP6+G(5,13)*SP6
      C7=G(13,7)*CP7+G(6,13)*SP7
      C8=G(13,8)*CP8+G(7,13)*SP8
      C9=G(13,9)*CP9+G(8,13)*SP9
      C10=G(13,10)*CP10+G(9,13)*SP10
      C11=G(13,11)*CP11+G(10,13)*SP11
      C12=G(13,12)*CP12+G(11,13)*SP12
      C13=G(13,13)*CP13+G(12,13)*SP13
      BR=BR-13.0*AOR*(G(13,1)*P131+C2*P132+C3*P133+C4*P134+C5*P135+C6*P1
     136+C7*P137+C8*P138+C9*P139+C10*P1310+C11*P1311+C12*P1312+C13*P1313
     2)
      BT=BT+AOR*(G(13,1)*DP131+C2*DP132+C3*DP133+C4*DP134+C5*DP135+C6*DP
     1136+C7*DP137+C8*DP138+C9*DP139+C10*DP1310+C11*DP1311+C12*DP1312+C1
     23*DP1313)
      BP=BP-AOR*((G(13,2)*SP2-G(1,13)*CP2)*P132+2.0*(G(13,3)*SP3-G(2,13)
     1*CP3)*P133+3.0*(G(13,4)*SP4-G(3,13)*CP4)*P134+4.0*(G(13,5)*SP5-G(4
     2,13)*CP5)*P135+5.0*(G(13,6)*SP6-G(5,13)*CP6)*P136+6.0*(G(13,7)*SP7
     3-G(6,13)*CP7)*P137+7.0*(G(13,8)*SP8-G(7,13)*CP8)*P138+8.0*(G(13,9)
     4*SP9-G(8,13)*CP9)*P139+9.0*(G(13,10)*SP10-G(9,13)*CP10)*P1310+10.0
     5*(G(13,11)*SP11-G(10,13)*CP11)*P1311+11.0*(G(13,12)*SP12-G(11,13)*
     6CP12)*P1312+12.0*(G(13,13)*SP13-G(12,13)*CP13)*P1313)
    1 BR = BR / 100000.
      BT = BT / 100000.
      BP = BP / ST / 100000.
      B =  SQRT(BR*BR+BT*BT+BP*BP )
      RETURN
      END

